##
# aims
# lib/error.pl
# Copyright (c) 2012 Matt Ferris
# Author: Matt Ferris
#

$E_PARSE_EXP = 1;
$E_PARSE_BADVAL = 2;
$E_PARSE_GENERAL = 4;
$E_FATAL_NOFILE = 8;
$E_HANDLER_NOEXIST = 16;
$E_VAR_NOTDEF = 32;
$E_FATAL_NOWRITE = 64;
$E_PARSE_NOHNDLR = 128;
$E_IFMOD_NOTDEF = 256;

##
# aims_err
#
# $errnum The error number
# 
# Raises the specified error
#
sub aims_err
{
	my $errnum = shift;
	my $msg;

	if ($errnum == $E_PARSE_EXP)
	{
		my $exp = shift;
		$msg = 'parse error: expected '.$exp;
	}
	elsif ($errnum == $E_PARSE_BADVAL)
	{
		my $got = shift;
		my $wanted = shift;
		$msg = "parse error: bad value for $wanted '$got'";
	}
	elsif ($errnum == $E_PARSE_GENERAL)
	{
		my $errmsg = shift;
		my $errrule = shift;
		$msg = 'parse error: '.$errmsg." near '@$errrule'";;
	}
	elsif ($errnum == $E_FATAL_NOFILE)
	{
		my $file = shift;
		$msg = "fatal: file '$file' doesn't exist";
	}
	elsif ($errnum == $E_FATAL_NOWRITE)
	{
		my $file = shift;
		$msg = "fatal: can't write to $file: $!";
	}
	elsif ($errnum == $E_HANDLER_NOEXIST)
	{
		my $cmd = shift;
		my $handler = shift;
		my $errrule = shift;
		$msg = "handler for $cmd ($handler) not found near '@$errrule'";
	}
	elsif ($errnum == $E_VAR_NOTDEF)
	{
		my $var = shift;
		my $varrule = shift;
		$msg = "variable '$var' hasn't been defined or is empty near '@$varrule'"; 
	}
	elsif ($errnum == $E_PARSE_NOHNDLR)
	{
		my $cmd = shift;
		my $errrule = shift;
		$msg = "empty handler for $cmd near '@$errrule'";
	}
	elsif ($errnum == $E_IFMOD_NOTDEF)
	{
		my $ifmod = shift;
		$msg = "invalid interface modifier '$ifmod' specified";
	}

	print STDERR 'aims: error: '.$msg."\n";
	exit 1;
}

return 1;
