##
# aims
# mod/nat.pl
# Copyright (c) 2012 Matt Ferris
# Author: Matt Ferris
#

##
# aimsmod_nat_init
#
# Registers handlers for masq, snat, dnat and nat
#
sub aimsmod_nat_init
{
	aimsapi_registerHandler('masq', 'nat_masq', 0, 1);
	aimsapi_registerHandler('snat', 'nat_snat', 0, 1);
	aimsapi_registerHandler('dnat', 'nat_dnat', 0, 1);
	aimsapi_registerHandler('nat', 'nat', 0, 1);
}

##
# aimsmod_nat
#
# Allows 'nat' to be used to conveniently identify
# nat rules. The work is actually done by the masq,
# snat, and dnat clauses.
#
sub aimsmod_nat
{
	return 1;
}

##
# aimsmod_nat_masq
#
# Sets the table to nat, the chain to postrouting
# and the target to masquerade.
#
sub aimsmod_nat_masq
{
	aimsapi_setBucket('table', '-t nat');
	aimsapi_setBucket('chain', '-A POSTROUTING');
	aimsapi_setBucket('target', '-j MASQUERADE');
}

##
# aimsmod_nat_snat
#
# $args The list of arguments
#
# Sets the table to nat, the chain to postrouting
# and the target to SNAT and --to-source
#
sub aimsmod_nat_snat
{
	my $args = shift;
	my $source = $args->[0];
	aimsapi_setBucket('table', '-t nat');
	aimsapi_setBucket('chain', '-A POSTROUTING');
	aimsapi_setBucket('target', '-j SNAT');
	aimsapi_pushBucket('target', "--to-source $source");
}

##
# aimsmod_nat_dnat
#
# $args The list of arguments
#
# Sets the table nat, the chain to prerouting
# and the target to DNAT and --to-destination
#
sub aimsmod_nat_dnat
{
	my $args = shift;
	my $dest = $args->[0];
	aimsapi_setBucket('table', '-t nat');
	aimsapi_setBucket('chain', '-A PREROUTING');
	aimsapi_setBucket('target', '-j DNAT');
	aimsapi_pushBucket('target', "--to-destination $dest");
}

return 1;
