##
# aims
# mod/on.pl
# Copyright (c) 2012 Matt Ferris
# Author: Matt Ferris
#

##
# aimsmod_on_init
#
# Registers the on, in and out handlers
#
sub aimsmod_on_init
{
	aimsapi_registerHandler('on', 'on', 1, 3);
	aimsapi_registerHandler('in', 'on_in', 1, 2);
	aimsapi_registerHandler('out', 'on_out', 1, 2);
}

##
# aimsmod_on
#
# $args The argument list
#
# Set the interface and direction of the traffic
# and optionally set the chain.
#
sub aimsmod_on
{
	my $ret;
	my $args = shift;
	my ($interface, $direction) = @$args;

	if (!$interface) { aims_err($E_PARSE_EXP, 'interface'); }

	if ($direction eq "egress") { $ret = '-o'; }
	elsif ($direction eq "ingress") { $ret = '-i'; }
	else
	{
		my $bucket = aimsapi_getBucket('chain');
		if ($bucket->[0] =~ /INPUT/) { $ret = '-i'; }
		elsif ($bucket->[0] =~ /OUTPUT/) { $ret = '-o'; }
		else { aims_err($E_PARSE_EXP, 'egress or ingress'); }
	}

	$ret .= ' '.$interface;
	aimsapi_pushBucket('expr', $ret);
}

##
# aimsmod_on_in
#
# $args The argument list
#
# Set the interface and direction and
# optionally set the chain
#
sub aimsmod_on_in
{
	my $args = shift;
	my ($if) = @$args;
	if (!$if) { aims_err($E_PARSE_EXP, 'interface'); }

	my $bucket = aimsapi_getBucket('chain');
	if ($bucket->[0] eq '')
	{
		aimsapi_setBucket('chain', '-A INPUT');
	}
	
	aimsapi_pushBucket('expr', '-i '.$if);
}

##
# aimsmod_on_out
#
# $args The argument list
#
# Set the interface and direction and
# optionally set the chain
#
sub aimsmod_on_out
{
	my $args = shift;
	my ($if) = @$args;
	if (!$if) { aims_err($E_PARSE_EXP, 'interface'); }

	my $bucket = aimsapi_getBucket('chain');
	if ($bucket->[0] eq '')
	{
		aimsapi_setBucket('chain', '-A OUTPUT');
	}
	
	aimsapi_pushBucket('expr', '-o '.$if);
}

return 1;
